@@ -15,12 +15,30 @@
 #' data[[1]] # users with links to genome data
 #' data[[2]] # users without links to genome data
 #' }
-
 users <- function(df = FALSE, ...) {
-  res <- os_GET(paste0(osnp_base(), "users.json"), list(), ...)
+  
+
+  tryCatch(
+    {
+      res <- os_GET(paste0(osnp_base(), "users.json"), list(), ...)
+      ## need to check what it returns
+      # Process the data or perform any desired operations
+    },
+    error = function(e) {
+      message("Failed to retrieve data from OpenSNP. Please check the URL or try again later.")
+      stop("Error - Failed to retrieve data from OpenSNP or connection is interrupted")
+    }
+    ,
+    warning = function(w) {
+      message("Warning: Data retrieval resulted in a warning.")
+      # Handle warnings if necessary
+      stop("Warning - Failed to retrieve data from OpenSNP or connection is interrupted")
+    }
+  )
+  
   users_ <- jsonlite::fromJSON(res, FALSE)
-  if (!df) { 
-    users_ 
+  if (!df) {
+    users_
   } else {
     lengths <- laply(users_, function(x) length(unlist(x)))
     getdffive <- function(x) {
